==> qtjambi-uic-6.5.1-sources.jar: io/qt/uic/ui4/DomButtonGroups.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class DomButtonGroups</p>
 */
public class DomButtonGroups extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomButtonGroups(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomButtonGroups instance);
    
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.uic.ui4.@Nullable DomButtonGroup> elementButtonGroup(){
        return elementButtonGroup_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.uic.ui4.DomButtonGroup> elementButtonGroup_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @QtUninvokable
    public final void setElementButtonGroup(java.util.@NonNull Collection<? extends io.qt.uic.ui4.@Nullable DomButtonGroup> a){
        setElementButtonGroup_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementButtonGroup_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomButtonGroup> a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected DomButtonGroups(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-6.5.2-sources.jar: io/qt/uic/ui4/DomButtonGroups.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomButtonGroups</code></p>
 */
public class DomButtonGroups extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomButtonGroups::<wbr>DomButtonGroups()</code></p>
     */
    public DomButtonGroups(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomButtonGroups instance);
    
    /**
     * <p>See <code>DomButtonGroups::<wbr>elementButtonGroup()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.uic.ui4.@Nullable DomButtonGroup> elementButtonGroup(){
        return elementButtonGroup_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.uic.ui4.DomButtonGroup> elementButtonGroup_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomButtonGroups::<wbr>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomButtonGroups::<wbr>setElementButtonGroup(QList&lt;DomButtonGroup*&gt;)</code></p>
     */
    @QtUninvokable
    public final void setElementButtonGroup(java.util.@NonNull Collection<? extends io.qt.uic.ui4.@Nullable DomButtonGroup> a){
        setElementButtonGroup_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementButtonGroup_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomButtonGroup> a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    /**
     * <p>See <code>DomButtonGroups::<wbr>write(QXmlStreamWriter&amp;,<wbr>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomButtonGroups(QPrivateConstructor p) { super(p); } 
    
}
